@@ -1,8 +1,23 @@
 public class Main {
     public static void main(String[] args) throws Exception {
         // invocation of void method. verify that it runs without error
+
+        Foo.toggle = false;
         Foo.hello();
+        assertEquals(true, Foo.toggle);
+
+        Foo.toggle = false;
         Foo.hello2();
+        assertEquals(true, Foo.toggle);
+
+        Foo.toggle = false;
+        new Foo().hello3();
+        assertEquals(true, Foo.toggle);
+
+        Foo.toggle = false;
+        new Foo().hello4();
+        assertEquals(true, Foo.toggle);
+
         Foo.unbox();
         Foo.box();
 
@@ -23,6 +38,14 @@ public class Main {
 
         // still a work in progress
 //        check((Bar)Bar.class.newInstance(),args[0]);
+
+        Adapter a = new Adapter();
+        assertEquals(1,a.i());
+        assertEquals("http://kohsuke.org/",a.o());
+
+        new Adapter.SomeClass().someMethod();
+
+        assertEquals(1,a.l());
     }
 
     private static void assertEquals(Object expected, Object actual) {
